# Medical stuff
Jab n°3
: :house: amstelveen
: :calendar: 14:03 on 18th 

## Ziekenhuis Amstelland

☎ Interne geneeskunde 
: (020) 755 7025

:phone: 020 755 7023 - Safkia


## Dental :: Tandartspraktijk Rijsenhout 

⌂
: Jolweg 25, 1435 KR Rijsenhout, Pays-Bas

☎
: 02 97 32 79 69


## Chiro :: Salvedo Health Clinic

⌂
: Maalderij 38, 1185 ZC Amstelveen

☎
: 02 0700 9343

